@@ -22,10 +22,6 @@ __all__ = strs('B32', 'B64')
 del strs
 
 
-__author__ = "Manuel Vázquez Acosta <mva.led@gmail.com>"
-__date__ = "Mon Mar 25 14:38:12 2013"
-
-
 class BaseConvertor(object):
     '''Base class that implements conversion algorithms based on a simple
     lookup table and a bit mask.
