@@ -20,9 +20,6 @@ from __future__ import (division as _py3_division,
                         unicode_literals as _py3_unicode,
                         absolute_import as _py3_abs_import)
 
-__docstring_format__ = 'rst'
-__author__ = 'med'
-
 
 def program_name():
     '''Calculate the program name from "sys.argv[0]".'''
