@@ -35,9 +35,6 @@ __all__ = slist('smart_getter', 'smart_getter_and_deleter',
                 'extract_attrs')
 del slist
 
-__docstring_format__ = 'rst'
-__author__ = 'manu'
-
 
 _INVALID_CLASS_TYPE_MSG = '``cls`` must be a class not an instance'
 
@@ -930,17 +927,18 @@ else:
 metaclass = __m.metaclass
 
 
-metaclass.__doc__ = '''Defines the metaclass of a class using a py3k-looking
-    style.
+metaclass.__doc__ = '''Define the metaclass of a class.
 
     .. versionadded:: 1.4.1
 
+    This function allows to define the metaclass of a class equally in Python
+    2 and 3.
+
     Usage::
 
        >>> class Meta(type):
        ...   pass
 
-       # This is the same as the Py3k syntax: class Foobar(metaclass=Meta)
        >>> class Foobar(metaclass(Meta)):
        ...   pass
 
@@ -953,6 +951,47 @@ metaclass.__doc__ = '''Defines the metaclass of a class using a py3k-looking
        >>> Spam.__bases__ == (dict, )
        True
 
+    .. versionadded:: 1.5.5 The `kwargs` keywords arguments with support for
+       ``__prepare__``.
+
+    Metaclasses are allowed to have a ``__prepare__`` classmethod to return
+    the namespace into which the body of the class should be evaluated.  See
+    :pep:`3115`.
+
+    .. warning:: The :pep:`3115` is not possible to implement in Python 2.7.
+
+       Despite our best efforts to have a truly compatible way of creating
+       meta classes in both Python 2.7 and 3.0+, there is an inescapable
+       difference in Python 2.7.  The :pep:`3115` states that ``__prepare__``
+       should be called before evaluating the body of the class.  This is not
+       possible in Python 2.7, since ``__new__`` already receives the
+       attributes collected in the body of the class.  So it's always too late
+       to call ``__prepare__`` at this point and the Python 2.7 interpreter
+       does not call it.
+
+       Our approach for Python 2.7 is calling it inside the ``__new__`` of a
+       "side" metaclass that is used for the base class returned.  This means
+       that ``__prepare__`` is called **only** for classes that use the
+       `metaclass`:func: directly.  In the following hierarchy::
+
+           class Meta(type):
+                @classmethod
+                def __prepare__(cls, name, bases, **kwargs):
+                    from xoutil.collections import OrderedDict
+                    return OrderedDict()
+
+           class Foo(metaclass(Meta)):
+                pass
+
+           class Bar(Foo):
+                pass
+
+       when creating the class ``Bar`` the ``__prepare__()`` class method is
+       not called in Python 2.7!
+
+    .. seealso:: `xoutil.types.prepare_class`:func: and
+       `xoutil.types.new_class`:func:.
+
     .. warning::
 
        You should always place your metaclass declaration *first* in the list
